crnt4sbml.LowDeficiencyApproach
=====================================

.. currentmodule:: crnt4sbml

.. autoclass:: LowDeficiencyApproach

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~LowDeficiencyApproach.__init__
      ~LowDeficiencyApproach.does_satisfy_deficiency_zero_theorem
      ~LowDeficiencyApproach.does_satisfy_deficiency_one_theorem
      ~LowDeficiencyApproach.does_satisfy_any_low_deficiency_theorem
      ~LowDeficiencyApproach.report_deficiency_zero_theorem
      ~LowDeficiencyApproach.report_deficiency_one_theorem
